summaryrefslogtreecommitdiffstats
path: root/ksim/library/progress.h
diff options
context:
space:
mode:
Diffstat (limited to 'ksim/library/progress.h')
-rw-r--r--ksim/library/progress.h25
1 files changed, 13 insertions, 12 deletions
diff --git a/ksim/library/progress.h b/ksim/library/progress.h
index 7f0f68a..40eca5c 100644
--- a/ksim/library/progress.h
+++ b/ksim/library/progress.h
@@ -33,6 +33,7 @@ namespace KSim
class KDE_EXPORT Progress : public KSim::Label
{
Q_OBJECT
+ TQ_OBJECT
public:
enum ProgressType { Panel, Meter };
/**
@@ -41,9 +42,9 @@ namespace KSim
* @param maxValue is the maximum value
* that the progress bar will show
* @param label is the text that will be displayed
* @param parent is the parent widget
*/
- Progress(int maxValue, TQWidget *parent,
+ Progress(int maxValue, TQWidget *tqparent,
const char *name = 0, WFlags fl = 0);
/**
* constructs a KSim::Progress
@@ -52,10 +53,10 @@ namespace KSim
* that the progress bar will show
* @param type is the theme type
* @param label is the text that will be displayed
* @param parent is the parent widget
*/
Progress(int maxValue, int type, const TQString &label,
- TQWidget *parent, const char *name = 0, WFlags fl = 0);
+ TQWidget *tqparent, const char *name = 0, WFlags fl = 0);
/**
* constructs a KSim::Progress
*
@@ -64,10 +65,10 @@ namespace KSim
* @param type is the theme type
* @param label is the text that will be displayed
* @param value is the initial value to be displayed
* @param parent is the parent widget
*/
Progress(int maxValue, int type, const TQString &label,
- int value, TQWidget *parent, const char *name = 0,
+ int value, TQWidget *tqparent, const char *name = 0,
WFlags fl = 0);
/**
* constructs a KSim::Progress
@@ -75,9 +76,9 @@ namespace KSim
* @param maxValue is the maximum value
* that the progress bar will show
* @param type is the theme type
* @param parent is the parent widget
*/
- Progress(int maxValue, int type, TQWidget *parent,
+ Progress(int maxValue, int type, TQWidget *tqparent,
const char *name = 0, WFlags fl = 0);
/**
* constructs a KSim::Progress
@@ -86,11 +87,11 @@ namespace KSim
* that the progress bar will show
* @param type is the theme type
* @param progressType is onr of Progress::ProgressType
* @param parent is the parent widget
*/
Progress(int maxValue, int type,
ProgressType progressType,
- TQWidget *parent, const char *name = 0,
+ TQWidget *tqparent, const char *name = 0,
WFlags fl = 0);
/**
* destructs KSim::Chart
@@ -117,11 +118,11 @@ namespace KSim
/**
* reimplemented for internal reasons
*/
- virtual void configureObject(bool repaintWidget = true);
+ virtual void configureObject(bool tqrepaintWidget = true);
/**
* reimplemented for internal reasons
*/
- virtual TQSize sizeHint() const;
+ virtual TQSize tqsizeHint() const;
public slots:
/**
@@ -41,9 +42,9 @@ namespace KSim
* that the progress bar will show
* @param label is the text that will be displayed
- * @param parent is the parent widget
+ * @param tqparent is the tqparent widget
*/
@@ -52,10 +53,10 @@ namespace KSim
* @param type is the theme type
* @param label is the text that will be displayed
- * @param parent is the parent widget
+ * @param tqparent is the tqparent widget
*/
Progress(int maxValue, int type, const TQString &label,
@@ -64,10 +65,10 @@ namespace KSim
* @param label is the text that will be displayed
* @param value is the initial value to be displayed
- * @param parent is the parent widget
+ * @param tqparent is the tqparent widget
*/
Progress(int maxValue, int type, const TQString &label,
@@ -75,9 +76,9 @@ namespace KSim
* that the progress bar will show
* @param type is the theme type
- * @param parent is the parent widget
+ * @param tqparent is the tqparent widget
*/
@@ -86,11 +87,11 @@ namespace KSim
* @param type is the theme type
* @param progressType is onr of Progress::ProgressType
- * @param parent is the parent widget
+ * @param tqparent is the tqparent widget
*/
Progress(int maxValue, int type,